# Changelog

All notable changes to this umed sms client project will be documented in this file.

## [1.0.0] - 2023-04-05

### Added

- Initial release of umed-sms-client library

[Unreleased]: https://github.com/hasithaprageeth/umed-sms-client/compare/v1.0.0...HEAD
[1.0.0]: https://github.com/hasithaprageeth/umed-sms-client/releases/tag/v1.0.0
